@@ -27,21 +27,7 @@
 #include <gtk/gtkwindow.h>
 
 #include "cd-drive.h"
-
-typedef void (*CancelFunc) (gpointer       data);
-
-enum {
-	RESULT_ERROR,
-	RESULT_CANCEL,
-	RESULT_FINISHED,
-	RESULT_RETRY
-};
-
-extern int write_iso (CDDrive *recorder,
-		      const char *filename,
-		      int speed,
-		      gboolean eject,
-		      gboolean dummy_write);
+#include "cd-recorder.h"
 
 extern int make_iso (const char *filename,
 		     const char *label);
